"""
    modp(n::Int, p::Int)::Int

Return 2^n modulo p (be aware of numerics).

# Examples

```jldoctest
julia> modp(3, 5)
3

julia> modp(1101, 101)
2

julia> modp(0, 101)
1

julia> modp(3, 11)
8

julia> modp(100, 101)
1
```
"""
function modp(n, p)
    result = 1
    base = 2 % p
    while n > 0
        if n % 2 == 1
            result = (result * base) % p
        end
        base = (base * base) % p
        n = n ÷ 2
    end
    return result
end
