"""
    max_fill(grid::Vector{Vector{Int}}, capacity::Int)::Int

You are given a rectangular grid of wells. Each row represents a single well,
and each 1 in a row represents a single unit of water. Each well has a
corresponding bucket that can be used to extract water from it, and all buckets
have the same capacity. Your task is to use the buckets to empty the wells.
Output the number of times you need to lower the buckets.

!!! note

    Constraints: * all wells have the same length * 1 <= grid.length <= 10^2 * 1 <= grid[:,1].length <= 10^2 * grid[i][j] -> 0 | 1 * 1 <= capacity <= 10

# Examples

```jldoctest
julia> max_fill([[0, 0, 1, 0], [0, 1, 0, 0], [1, 1, 1, 1]], 1)
6

julia> max_fill([[0, 0, 1, 1], [0, 0, 0, 0], [1, 1, 1, 1], [0, 1, 1, 1]], 2)
5

julia> max_fill([[0, 0, 0], [0, 0, 0]], 5)
0
```
"""
function max_fill(grid, capacity)
    total_water = sum(sum(row) for row in grid)
    num_wells = length(grid)
    
    bucket_fills = 0
    while total_water > 0
        for well in grid
            water_extracted = min(sum(well), capacity)
            total_water -= water_extracted
            
            if water_extracted > 0
                for i in 1:length(well)
                    if well[i] == 1
                        well[i] = 0
                        water_extracted -= 1
                        if water_extracted == 0
                            break
                        end
                    end
                end
                bucket_fills += 1
            end
        end
    end
    
    return bucket_fills
end
